==> org-lsst-ccs-subsystem-fcs-main-5.3.15-sources.jar: org/lsst/ccs/subsystems/fcs/drivers/TempMonitorDevice.java <==

package org.lsst.ccs.subsystems.fcs.drivers;

import org.lsst.ccs.Subsystem;
import org.lsst.ccs.services.alert.AlertService;
import org.lsst.ccs.commons.annotations.LookupField;
import org.lsst.ccs.monitor.Device;
import org.lsst.ccs.subsystems.fcs.FCSCst;
import static org.lsst.ccs.subsystems.fcs.FcsEnumerations.FcsAlert.HARDWARE_ERROR;
import org.lsst.ccs.subsystems.fcs.common.AlertRaiser;
import org.lsst.ccs.subsystems.fcs.errors.FcsHardwareException;
import org.lsst.ccs.utilities.logging.Logger;

/**
 *
 * A Class for the device which records temperatures in autochanger. For
 * autochanger final products, there are 2 devices CanOpenSeneca4RTD with 4
 * channels each. For the autochanger prototype, this device is a canopenSystec
 * IO X5 with 8 chanels, one chanel for each thermometer. This class uses the
 * monitoring framework so it extends Device. It delegates to its field
 * tempSensorsDevice the commands relative to a CanOpenDevice.
 *
 * @author virieux
 */
public class TempMonitorDevice extends Device implements AlertRaiser {

    protected static final Logger FCSLOG = FCSCst.FCSLOG;

    @LookupField(strategy = LookupField.Strategy.TREE)
    private AlertService alertService;

    double[] temperatures;

    MonitorDeviceInterface tempSensorsDevice;


    public TempMonitorDevice(MonitorDeviceInterface tempSensorsDevice) {
        this.tempSensorsDevice = tempSensorsDevice;
    }

    @Override
    public AlertService getAlertService() {
        return alertService;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public Subsystem getSubsystem() {
        return s;
    }

    @Override
    public void postStart() {
        FCSLOG.fine(name + " BEGIN postStart.");
        if (tempSensorsDevice.isBooted()) {
            initializePostStart();
        }
        FCSLOG.fine(name + " END postStart.");
    }

    public void initializePostStart() {
        try {
            tempSensorsDevice.initialize();
            setOnline(true);
            temperatures = new double[9];
            for (int i = 1; i < 9; i++) {
                temperatures[i] = 0;
            }

        } catch (FcsHardwareException ex) {
            this.raiseAlarm(HARDWARE_ERROR, " could not initialize temperature sensor device",
                    tempSensorsDevice.getName(), ex);
        }
    }

    @Override
    public void initialize() {
        // TODO get rid of that when Device will not call initialize in
        // checkHardwareMethod.
    }

    public double[] readTemperatures() {
        return temperatures;
    }

    @Override
    protected void close() {
        /* nothing to do here because closing is done in the CANbus layer. */
    }

    @Override
    public double readChannel(int chanelNO, int type) {
        double temp = temperatures[chanelNO];
        try {
            temp = (double) tempSensorsDevice.readChannel(chanelNO);

        } catch (Exception ex) {
            FCSLOG.warning(getName() + " : couldn't read temperatures", ex);
        }
        return temp;
    }

}

==> org-lsst-ccs-subsystem-fcs-main-5.4.4-sources.jar: org/lsst/ccs/subsystems/fcs/drivers/TempMonitorDevice.java <==

package org.lsst.ccs.subsystems.fcs.drivers;

import org.lsst.ccs.Subsystem;
import org.lsst.ccs.services.alert.AlertService;
import org.lsst.ccs.commons.annotations.LookupField;
import static org.lsst.ccs.commons.annotations.LookupField.Strategy.TREE;
import org.lsst.ccs.monitor.Device;
import org.lsst.ccs.subsystems.fcs.FCSCst;
import static org.lsst.ccs.subsystems.fcs.FcsEnumerations.FcsAlert.HARDWARE_ERROR;
import org.lsst.ccs.subsystems.fcs.common.AlertRaiser;
import org.lsst.ccs.subsystems.fcs.errors.FcsHardwareException;
import org.lsst.ccs.utilities.logging.Logger;

/**
 *
 * A Class for the device which records temperatures in autochanger. For
 * autochanger final products, there are 2 devices CanOpenSeneca4RTD with 4
 * channels each. For the autochanger prototype, this device is a canopenSystec
 * IO X5 with 8 chanels, one chanel for each thermometer. This class uses the
 * monitoring framework so it extends Device. It delegates to its field
 * tempSensorsDevice the commands relative to a CanOpenDevice.
 *
 * @author virieux
 */
public class TempMonitorDevice extends Device implements AlertRaiser {

    protected static final Logger FCSLOG = FCSCst.FCSLOG;

    @LookupField(strategy = TREE)
    private AlertService alertService;

    double[] temperatures;

    MonitorDeviceInterface tempSensorsDevice;


    public TempMonitorDevice(MonitorDeviceInterface tempSensorsDevice) {
        this.tempSensorsDevice = tempSensorsDevice;
    }

    @Override
    public AlertService getAlertService() {
        return alertService;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public Subsystem getSubsystem() {
        return s;
    }

    @Override
    public void postStart() {
        FCSLOG.fine(name + " BEGIN postStart.");
        if (tempSensorsDevice.isBooted()) {
            initializePostStart();
        }
        FCSLOG.fine(name + " END postStart.");
    }

    public void initializePostStart() {
        try {
            tempSensorsDevice.initialize();
            setOnline(true);
            temperatures = new double[9];
            for (int i = 1; i < 9; i++) {
                temperatures[i] = 0;
            }

        } catch (FcsHardwareException ex) {
            this.raiseAlarm(HARDWARE_ERROR, " could not initialize temperature sensor device",
                    tempSensorsDevice.getName(), ex);
        }
    }

    @Override
    public void initialize() {
        // TODO get rid of that when Device will not call initialize in
        // checkHardwareMethod.
    }

    public double[] readTemperatures() {
        return temperatures;
    }

    @Override
    protected void close() {
        /* nothing to do here because closing is done in the CANbus layer. */
    }

    @Override
    public double readChannel(int chanelNO, int type) {
        double temp = temperatures[chanelNO];
        try {
            temp = (double) tempSensorsDevice.readChannel(chanelNO);

        } catch (Exception ex) {
            FCSLOG.warning(getName() + " : couldn't read temperatures", ex);
        }
        return temp;
    }

}
